"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.slashCmdAuth = void 0;
const noble_ed25519_1 = require("noble-ed25519");
function slashCmdAuth({ PUBLIC_KEY }) {
    return async function (req, res, next) {
        if (req.method !== 'POST') {
            return res.sendStatus(405);
        }
        const signature = req.headers['x-signature-ed25519'];
        const timestamp = req.headers['x-signature-timestamp'];
        if (!signature || !timestamp) {
            return res.sendStatus(401);
        }
        const hash = Buffer.concat([
            Buffer.from(timestamp, 'utf-8'),
            Buffer.from(JSON.stringify(req.body)),
        ]);
        const isSigned = await noble_ed25519_1.verify(signature, hash, PUBLIC_KEY);
        if (!isSigned) {
            return res.sendStatus(401);
        }
        if (req.body.type === 1) {
            return res.json({ type: 1 });
        }
        next();
        return;
    };
}
exports.slashCmdAuth = slashCmdAuth;
//# sourceMappingURL=slashCmdAuth.js.map